/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RecipientFederationPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.83.0/docs/resources/recipient_federation_policy#comment RecipientFederationPolicy#comment}
    */
    readonly comment?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.83.0/docs/resources/recipient_federation_policy#name RecipientFederationPolicy#name}
    */
    readonly name?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.83.0/docs/resources/recipient_federation_policy#oidc_policy RecipientFederationPolicy#oidc_policy}
    */
    readonly oidcPolicy?: RecipientFederationPolicyOidcPolicy;
}
export interface RecipientFederationPolicyOidcPolicy {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.83.0/docs/resources/recipient_federation_policy#audiences RecipientFederationPolicy#audiences}
    */
    readonly audiences?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.83.0/docs/resources/recipient_federation_policy#issuer RecipientFederationPolicy#issuer}
    */
    readonly issuer: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.83.0/docs/resources/recipient_federation_policy#subject RecipientFederationPolicy#subject}
    */
    readonly subject: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.83.0/docs/resources/recipient_federation_policy#subject_claim RecipientFederationPolicy#subject_claim}
    */
    readonly subjectClaim: string;
}
export declare function recipientFederationPolicyOidcPolicyToTerraform(struct?: RecipientFederationPolicyOidcPolicy | cdktf.IResolvable): any;
export declare function recipientFederationPolicyOidcPolicyToHclTerraform(struct?: RecipientFederationPolicyOidcPolicy | cdktf.IResolvable): any;
export declare class RecipientFederationPolicyOidcPolicyOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): RecipientFederationPolicyOidcPolicy | cdktf.IResolvable | undefined;
    set internalValue(value: RecipientFederationPolicyOidcPolicy | cdktf.IResolvable | undefined);
    private _audiences?;
    get audiences(): string[];
    set audiences(value: string[]);
    resetAudiences(): void;
    get audiencesInput(): string[] | undefined;
    private _issuer?;
    get issuer(): string;
    set issuer(value: string);
    get issuerInput(): string | undefined;
    private _subject?;
    get subject(): string;
    set subject(value: string);
    get subjectInput(): string | undefined;
    private _subjectClaim?;
    get subjectClaim(): string;
    set subjectClaim(value: string);
    get subjectClaimInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/databricks/databricks/1.83.0/docs/resources/recipient_federation_policy databricks_recipient_federation_policy}
*/
export declare class RecipientFederationPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "databricks_recipient_federation_policy";
    /**
    * Generates CDKTF code for importing a RecipientFederationPolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the RecipientFederationPolicy to import
    * @param importFromId The id of the existing RecipientFederationPolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/databricks/databricks/1.83.0/docs/resources/recipient_federation_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the RecipientFederationPolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.83.0/docs/resources/recipient_federation_policy databricks_recipient_federation_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RecipientFederationPolicyConfig = {}
    */
    constructor(scope: Construct, id: string, config?: RecipientFederationPolicyConfig);
    private _comment?;
    get comment(): string;
    set comment(value: string);
    resetComment(): void;
    get commentInput(): string | undefined;
    get createTime(): string;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _oidcPolicy;
    get oidcPolicy(): RecipientFederationPolicyOidcPolicyOutputReference;
    putOidcPolicy(value: RecipientFederationPolicyOidcPolicy): void;
    resetOidcPolicy(): void;
    get oidcPolicyInput(): cdktf.IResolvable | RecipientFederationPolicyOidcPolicy | undefined;
    get updateTime(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
